# Gump SDK 4 for Android接入文档

V4.9.5       
2023年09月08日


## 版本概述

此版本为使用AndroidStudio开发的版本,使用aar的方式提供sdk接入包,并使用gradle在线依赖方式,aar内别不包含依赖包,请按此文档描述接入.

此SDK适用android4.0以上系统.

## 第一章  接入指南
### 1.依赖导入    
配置gradle,以下为必须项    

```groovy
repositories{
    maven{
    	url "http://117.50.8.198:8081/nexus/content/repositories/sdk"
	}
}
dependencies {
    implementation 'com.gumptech.sdk:GameSDK:4.9.5'

}
```


### 2.修改AndroidManifest.xml文件
首先添加必要的权限，如下所示：  

```xml
<uses-permission android:name="android.permission.INTERNET" />
<uses-permission android:name="android.permission.ACCESS_WIFI_STATE" />
<uses-permission android:name="android.permission.ACCESS_NETWORK_STATE"/>
<uses-permission android:name="com.google.android.gms.permission.AD_ID"/>
```

其次注册相应的Activity，具体如下：  

```xml
<activity
        android:name="com.gump.game.sdk.PassportActivity"
        android:configChanges="orientation|screenSize|keyboardHidden|keyboard|screenLayout"
        android:launchMode="singleTask"
        android:theme="@style/Theme.Origin" //登录界面的主题,可选项:Theme.Origin\Theme.Orange\Theme.Blue\Theme.Pink
        android:screenOrientation="behind"
        android:windowSoftInputMode="stateAlwaysHidden|adjustPan">
</activity>
<activity
    android:name="com.gump.game.sdk.RechargeActivity"
    android:configChanges="orientation|screenSize|keyboardHidden|keyboard|screenLayout"
    android:launchMode="singleTask"
	android:screenOrientation="behind"
    android:theme="@style/Theme.Translucent" >
    <intent-filter>
        <category android:name="android.intent.category.DEFAULT" />
        <action android:name="android.intent.action.VIEW" />
        <category android:name="android.intent.category.BROWSABLE" />
        <data
            android:host="com.gump.sdk"
            android:scheme="gump+游戏的appId" />
    </intent-filter>
</activity>
```

### 3.向Gump平台索要游戏ID（AppID），完成代码接入     
正式开始接入逻辑代码前,先介绍下一些附加设置,以方便代码接入  

*是否打印debug日志    

```java
GameSDK.getSettings().enableDebugLogging(true); 
```

*设置需要启用的第三方登录，参数可选类型见第二章：[第三方登录平台](http://repository.gumptech.com:81/document/gamesdk4-android/blob/master/IntegrationGuide.md#1-third_plat) 字段说明

```java
GameSDK.getSettings().requestThirdSupport(SDKSettings.THIRD_SUPPORT_*)；
```


#### 1.调用GameSDK前需要执行初始化。     

若不需要分渠道      

```java
GameSDK.init(Context,Appid);   
```
如果需要定义渠道,必须使用如下方法       

```java
GameSDK.init(Context,Appid,ChannelId);   
```


#### 2.调用GameSDK的登录方法,将执行登录流程,需要一个Activity实例作参数       

```java
GameSDK.login(Activity);  
```
在此之前,开发者需要注册用户状态监听以接受用户的登录/登出通知,通常如下:    

```java
GameSDK.setUserStateListener(new LoginStateListener() {
    
     	@Override
        public void onCreateUser() {
           //新用户注册,用于事件打点。勿阻塞此方法,否则影响登录流程
            Log.i(TAG,"Someone registers an new Account");
        }
    
        @Override
        public void onLoginSuccess(GumpUser gumpUser) {
            //登录成功,用户信息包含在GumpUser对象里
        }

        @Override
        public void onLoginFailed(int code, String msg) {
            //登录出错,根据错误码和信息判断错误类型
            Toast.makeText(MainActivity.this, "Login failed:code="+code+",message="+msg, Toast.LENGTH_SHORT).show();
        }

        @Override
        public void onLoginCanceled() {
            //用户取消登录
            Toast.makeText(MainActivity.this, "operate be canceled", Toast.LENGTH_SHORT).show();
        }

        @Override
        public void onLogout() {
            //用户登出
            
        }
     @Override
        public void onPermissionDenied(String[] deniedPermissions) {
		//用户未授予权限,参数为没有获取的权限
        }
    });
```

如上成功登录后收到的GumpUser对象包含以下信息  

```java
gumpUser.getUid();//获取用户的userid,此Id标识唯一用户!  
gumpUser.getAccountType();//用户类型,此类型数据可从GumpPreference常量获取  
gumpUser.getSessionKey();//登录的sessionKey对象,获取sessionKey字符串请使用此对象的getToken()方法  
```

#### 3.支付功能  
调用支付前需先判断支付状态,根据状态调用支付方法  

```java
GameSDK.iapUsable(Activity, serverId, roleId, new ResultCallback() {
                @Override
                public void onResult(boolean result) {
                    if(result){
					//调用GameSDK.iap
					}else{
					//调用GameSDK.pay
					}	
                }
            });
```

1)调用GameSDK.pay     

```java
Bundle payInfo = new Bundle();
payInfo.putString("product", "元宝");
payInfo.putFloat("amount", 40.0f);
payInfo.putString("extraInfo", "This is demo!");
payInfo.putString("serverId", "B4003");
payInfo.putString("roleId", "10010");
payInfo.putString("currency","currency");
GumpSDK.pay(MainActivity.this, payInfo,PurchaseCallback);
```
调用pay方法时,必须传入一个bundle对象,包含如上字段,所有字段必须全部包含  
    
    
2)IAP支付   
    

```java
Bundle payInfo = new Bundle();
payInfo.putString("product", "gp_skuId");
payInfo.putFloat("amount", 0.1f);
payInfo.putString("extraInfo", "This is demo!");
payInfo.putString("serverId", "100");
payInfo.putString("roleId","100123");
GumpSDK.iap(MainActivity.this, payInfo, PurchaseCallback);
```

3)PurchaseCallback为支付状态回调接口,此接口含有3个方法  

```java
@Override
public void onPurchaseCompleted() {
    Log.i(TAG,"purchase completed");
}

@Override
public void onPurchaseError(int code, String msg) {
    Log.i(TAG,"purchase error");
}

@Override
public void onPurchaseCanceled() {
    Log.i(TAG,"purchase canceled");
}
```

#### 4.注销登录      

```java
GameSDK.logout(Activity);
```
当此方法调用后,用户退出登录,并会通过LoginStateListener接口通知调用程序!为了便于用户切换登录账户,请在游戏内提供用户注销的触发按钮   
#### 5.运营开关接口，若需要接入，会有我方运营人员提出需求，否则不需要接入（若对此接口不知所云，即可认为不需要接入，请自行忽略）

```java
GameSDK.inspectRiskLevel(this, new ResultCallback() {
        @Override
        public void onResult(boolean result) {
            Log.i(TAG,result?"There is some risks":"Nothing is risk");
        }
    });
```

## 第二章 常量字段与代码
### 1.第三方登录平台(third_plat)
	|         常量字段                |    说明       |
	|--------------------------------|--------------|
	|SDKSettings.THIRD_SUPPORT_FB    | Facebook登录  |
	|SDKSettings.THIRD_SUPPORT_GOOGLE| Google登录    |
	|SDKSettings.THIRD_SUPPORT_LINE  | Line登录      |

### 2.登录账户类型
	|               常量字段               |      说明     |
	|-------------------------------------|--------------|
	|GumpPreference.ACCOUNT_TYPE_FB       | Facebook用户  |
	|GumpPreference.ACCOUNT_TYPE_REG      | Gump注册用户  |
	|GumpPreference.ACCOUNT_TYPE_QUICK_REG| 游客          |
	|GumpPreference.ACCOUNT_TYPE_GOOGLE   | Google用户    |
	|GumpPreference.ACCOUNT_TYPE_LINE     | Line用户      |



## 第三章 常见问题      
### 问题1： 如何避免混淆对SDK的影响？       
解答：有些开发者对接入了SDK的程序进行混淆时，有可能会覆盖某些java
类，导致SDK无法正常工作，解决方法如下:      
Ø  请开发者在混淆配置文件proguard.cfg或proguard-project.txt的最后加上       

    -keepattributes *Annotation*,InnerClasses,SourceFile,LineNumberTable
    -keep public class * extends android.app.Service
    -keep public class com.google.vending.licensing.ILicensingService
    -keep public class com.android.vending.licensing.ILicensingService
    -keep class com.gump.game.sdk.view.* {*;}
    -keep class com.gump.game.sdk.web.* {*;}


​    
使得混淆的时候不会影响SDK的命名空间。